% lower probability interval (PRI) transition matrix
Lpri = [.4 .0 .2
        .0 .5 .3
        .0 .0 .5];

% upper PRI transition matrix
Upri=[.8 .4 .4 
    .2 .7 .5
    .1 .5 1];

% initial lower PRI
initLPri = [0 1 0];

% initial upper PRI
initUPri = [0 1 0];


% output filename 
out = fopen ('markov_pri.out', 'w');

% the list of iterations for output
iter = [1, 2, 3, 5, 20];

% the number of states
n = length(initLPri);

% the indicator functions of all subsets of 
% the set of the size n
% Example ( n=3 ):
% f =
% 
%      1     0     0
%      0     1     0
%      1     1     0
%      0     0     1
%      1     0     1
%      0     1     1
f = fnalsLP(n);

% generate initial lower probability
Linitial = pri2lp(initLPri, initUPri);

% generate lower transition matrix
L = pri2lpMatrix(Lpri, Upri);

% write initial lower probability
fprintf(out, 'Initial\t\t');
fprintf(out, '%6.4f\t', Linitial);
fprintf(out, '\n\n');
	
for it=1:length(iter)
    % write the results for each number of steps from 
    % the list 'iter' to the output file
	fprintf(out, 'Iteration %2.0f\t', iter(it));
	Lb = markovSteps ( f, Linitial, L, iter(it));	
	fprintf(out,  '%6.4f\t', Lb );
	fprintf(out,  '\n\n');	
end

fclose (out);

