% do you want to plot results?
pl = 'yes';

% lower transition matrix:
%  rows: states
%  columns: subsets
L = [ 0.3000    0.4000    0.8000         0    0.5000    0.5000
    0.2000    0.6000    0.8000    0.1000    0.3000    0.7000
         0    0.3000    0.4000    0.5000    0.6000    0.9000]; 

% the indicator functions of all subsets of 
% the set of the size n
% Example ( n=3 ):
% f =
% 
%      1     0     0
%      0     1     0
%      1     1     0
%      0     0     1
%      1     0     1
%      0     1     1

f = fnalsLP(length(L(:, 1))); 

% initial lower probability
Linitial = [0.1, 0.1, 0.2, 0.1, 0.2 0.2];
 
% output filename 
out = fopen ('markov.out', 'w');

% the list of iterations for output
iter = [1, 3, 8, 10];

% write initial lower probability
fprintf(out, 'Initial\t\t');
fprintf(out, '%6.4f\t', Linitial);
fprintf(out, '\n\n');
	
parfor it=1:length(iter)
    % write the results for each number of steps from 
    % the list 'iter' to the output file
	fprintf(out, 'Iteration %2.0f\t', iter(it));
	Lb(it,:) = markovSteps ( f, Linitial, L, iter(it));
	fprintf(out,  '%6.4f\t', Lb(it, :) );
	fprintf(out,  '\n\n');	    
end

% generating plots
if (strcmp(pl, 'yes')) 
    triangle = prob3dto2d([1,0,0; 0,0,1; 0,1,0]);
    trix = triangle(:, 1);
    triy = triangle(:, 2);
    hold off;
    
    axis off;
    plot(trix, triy, 'blue');
    hold all;
    axis off;
    plot(trix, zeros(length(trix)), 'blue');
    hold all;
    parfor i =1:length(L(:, 1))
        probs = gridProbs(length(L(:,1)), f, L(i,:), 0.003+0.001*rand());
        probs2d = prob3dto2d(probs);
        x = probs2d(:,1); y = probs2d(:, 2);
        s = 2*ones(1, length(x));        
        axis off;
        scatter(x, y, s);
        hold all;
        pause;
    end
    
    for it =1:length(iter)
        probs = gridProbs(length(L(:,1)), f, Lb(it,:), 0.003+0.001*rand());
        probs2d = prob3dto2d(probs);
        x = probs2d(:,1); y = probs2d(:, 2);
        s = it*ones(1, length(x));        
        axis off;
        scatter(x, y, s);
        pause;
        hold on;
    end
    hold off;
end
fclose( out ); 